Settings for a minimal Datalevin-backed Memento cache.
Settings for a minimal Datalevin-backed Memento cache.
Value for :memento.core/type setting for filecache.
Value for :memento.core/type setting for filecache.
Caller-managed Datalevin KV connection. It can be a KV object, an IDeref, or a 0-arg fn.
The caller is responsible for Datalevin/LMDB lifecycle rules: keep exactly one open KV connection per filesystem path per JVM, share it across all caches that use that path, and close it once at application shutdown.
Caller-managed Datalevin KV connection. It can be a KV object, an IDeref, or a 0-arg fn. The caller is responsible for Datalevin/LMDB lifecycle rules: keep exactly one open KV connection per filesystem path per JVM, share it across all caches that use that path, and close it once at application shutdown.
Datalevin DBI name used for cached entries. Defaults to "memento-filecache".
Datalevin DBI name used for cached entries. Defaults to "memento-filecache".
Datalevin KV directory or URI. When provided, this cache opens the KV lazily.
Datalevin KV directory or URI. When provided, this cache opens the KV lazily.
Options passed to datalevin.core/open-kv when dir is used.
Options passed to datalevin.core/open-kv when dir is used.
(start-tracking! cache)Start tracking cache keys read by this filecache instance. Returns cache.
Start tracking cache keys read by this filecache instance. Returns cache.
(sweep-untracked! cache)Delete cache entries not seen since start-tracking!. Returns cache.
Delete cache entries not seen since start-tracking!. Returns cache.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |